@@ -3,7 +3,7 @@
 use crate::deserialize::utf8::read_input_to_buf;
 use crate::deserialize::DeserializeError;
 use crate::typeref::EMPTY_UNICODE;
-use std::ptr::NonNull;
+use core::ptr::NonNull;
 
 pub fn deserialize(
     ptr: *mut pyo3_ffi::PyObject,
@@ -21,15 +21,7 @@ pub fn deserialize(
         }
     }
 
-    let buffer_str = unsafe { std::str::from_utf8_unchecked(buffer) };
+    let buffer_str = unsafe { core::str::from_utf8_unchecked(buffer) };
 
-    #[cfg(feature = "yyjson")]
-    {
-        crate::deserialize::yyjson::deserialize_yyjson(buffer_str)
-    }
-
-    #[cfg(not(feature = "yyjson"))]
-    {
-        crate::deserialize::json::deserialize_json(buffer_str)
-    }
+    crate::deserialize::backend::deserialize(buffer_str)
 }
