@@ -32,15 +32,18 @@ impl<'a> Serialize for DefaultSerializer<'a> {
                 let default_obj = ffi!(PyObject_CallFunctionObjArgs(
                     callable.as_ptr(),
                     self.previous.ptr,
-                    std::ptr::null_mut() as *mut pyo3_ffi::PyObject
+                    core::ptr::null_mut() as *mut pyo3_ffi::PyObject
                 ));
                 #[cfg(Py_3_10)]
+                #[allow(clippy::cast_sign_loss)]
+                let nargs = ffi!(PyVectorcall_NARGS(1)) as usize;
+                #[cfg(Py_3_10)]
                 let default_obj = unsafe {
                     pyo3_ffi::PyObject_Vectorcall(
                         callable.as_ptr(),
-                        std::ptr::addr_of!(self.previous.ptr),
-                        pyo3_ffi::PyVectorcall_NARGS(1) as usize,
-                        std::ptr::null_mut(),
+                        &raw const self.previous.ptr,
+                        nargs,
+                        core::ptr::null_mut(),
                     )
                 };
                 if unlikely!(default_obj.is_null()) {
