@@ -9,7 +9,8 @@ use crate::serialize::per_type::{
 };
 use crate::serialize::serializer::PyObjectSerializer;
 use crate::serialize::state::SerializerState;
-use crate::typeref::*;
+use crate::typeref::{LIST_TYPE, TUPLE_TYPE};
+use crate::util::isize_to_usize;
 
 use core::ptr::NonNull;
 use serde::ser::{Serialize, SerializeSeq, Serializer};
@@ -49,8 +50,8 @@ impl ListTupleSerializer {
             is_type!(ob_type!(ptr), LIST_TYPE)
                 || is_subclass_by_flag!(tp_flags!(ob_type!(ptr)), Py_TPFLAGS_LIST_SUBCLASS)
         );
-        let data_ptr = unsafe { (*(ptr as *mut pyo3_ffi::PyListObject)).ob_item };
-        let len = ffi!(Py_SIZE(ptr)) as usize;
+        let data_ptr = unsafe { (*ptr.cast::<pyo3_ffi::PyListObject>()).ob_item };
+        let len = isize_to_usize(ffi!(Py_SIZE(ptr)));
         Self {
             data_ptr: data_ptr,
             len: len,
@@ -68,8 +69,8 @@ impl ListTupleSerializer {
             is_type!(ob_type!(ptr), TUPLE_TYPE)
                 || is_subclass_by_flag!(tp_flags!(ob_type!(ptr)), Py_TPFLAGS_TUPLE_SUBCLASS)
         );
-        let data_ptr = unsafe { (*(ptr as *mut pyo3_ffi::PyTupleObject)).ob_item.as_ptr() };
-        let len = ffi!(Py_SIZE(ptr)) as usize;
+        let data_ptr = unsafe { (*ptr.cast::<pyo3_ffi::PyTupleObject>()).ob_item.as_ptr() };
+        let len = isize_to_usize(ffi!(Py_SIZE(ptr)));
         Self {
             data_ptr: data_ptr,
             len: len,
