@@ -571,46 +571,23 @@ macro_rules! reserve_str {
     };
 }
 
-#[cfg(all(feature = "unstable-simd", not(target_arch = "x86_64")))]
-#[inline(always)]
-fn format_escaped_str<W>(writer: &mut W, value: &str)
-where
-    W: ?Sized + io::Write + WriteExt,
-{
-    unsafe {
-        reserve_str!(writer, value);
-
-        let written = crate::serialize::writer::str::format_escaped_str_impl_generic_128(
-            writer.as_mut_buffer_ptr(),
-            value.as_bytes().as_ptr(),
-            value.len(),
-        );
-
-        writer.set_written(written);
-    }
-}
-
-#[cfg(all(feature = "unstable-simd", target_arch = "x86_64", feature = "avx512"))]
+#[cfg(all(target_arch = "x86_64", feature = "avx512"))]
 type StrFormatter = unsafe fn(*mut u8, *const u8, usize) -> usize;
 
-#[cfg(all(feature = "unstable-simd", target_arch = "x86_64", feature = "avx512"))]
+#[cfg(all(target_arch = "x86_64", feature = "avx512"))]
 static mut STR_FORMATTER_FN: StrFormatter =
     crate::serialize::writer::str::format_escaped_str_impl_sse2_128;
 
 pub fn set_str_formatter_fn() {
     unsafe {
-        #[cfg(all(feature = "unstable-simd", target_arch = "x86_64", feature = "avx512"))]
+        #[cfg(all(target_arch = "x86_64", feature = "avx512"))]
         if std::is_x86_feature_detected!("avx512vl") {
             STR_FORMATTER_FN = crate::serialize::writer::str::format_escaped_str_impl_512vl;
         }
     }
 }
 
-#[cfg(all(
-    feature = "unstable-simd",
-    target_arch = "x86_64",
-    not(feature = "avx512")
-))]
+#[cfg(all(target_arch = "x86_64", not(feature = "avx512")))]
 #[inline(always)]
 fn format_escaped_str<W>(writer: &mut W, value: &str)
 where
@@ -629,7 +606,7 @@ where
     }
 }
 
-#[cfg(all(feature = "unstable-simd", target_arch = "x86_64", feature = "avx512"))]
+#[cfg(all(target_arch = "x86_64", feature = "avx512"))]
 #[inline(always)]
 fn format_escaped_str<W>(writer: &mut W, value: &str)
 where
@@ -648,7 +625,11 @@ where
     }
 }
 
-#[cfg(all(not(feature = "unstable-simd"), not(target_arch = "x86_64")))]
+#[cfg(all(
+    not(target_arch = "x86_64"),
+    not(feature = "avx512"),
+    feature = "generic_simd"
+))]
 #[inline(always)]
 fn format_escaped_str<W>(writer: &mut W, value: &str)
 where
@@ -657,7 +638,7 @@ where
     unsafe {
         reserve_str!(writer, value);
 
-        let written = crate::serialize::writer::str::format_escaped_str_scalar(
+        let written = crate::serialize::writer::str::format_escaped_str_impl_generic_128(
             writer.as_mut_buffer_ptr(),
             value.as_bytes().as_ptr(),
             value.len(),
@@ -667,7 +648,7 @@ where
     }
 }
 
-#[cfg(all(not(feature = "unstable-simd"), target_arch = "x86_64"))]
+#[cfg(all(not(target_arch = "x86_64"), not(feature = "generic_simd")))]
 #[inline(always)]
 fn format_escaped_str<W>(writer: &mut W, value: &str)
 where
@@ -676,7 +657,7 @@ where
     unsafe {
         reserve_str!(writer, value);
 
-        let written = crate::serialize::writer::str::format_escaped_str_impl_sse2_128(
+        let written = crate::serialize::writer::str::format_escaped_str_scalar(
             writer.as_mut_buffer_ptr(),
             value.as_bytes().as_ptr(),
             value.len(),
