@@ -43,12 +43,12 @@ pub const QUOTE_TAB: [[u8; 8]; 96] = [
     [b'\\', b'u', b'0', b'0', b'0', b'5', 0, 6],
     [b'\\', b'u', b'0', b'0', b'0', b'6', 0, 6],
     [b'\\', b'u', b'0', b'0', b'0', b'7', 0, 6],
-    [b'\\', b'b', 0, 0, 0, 0, 0, 2],
-    [b'\\', b't', 0, 0, 0, 0, 0, 2],
-    [b'\\', b'n', 0, 0, 0, 0, 0, 2],
-    [b'\\', b'u', 0, 0, 0, b'b', 0, 2],
-    [b'\\', b'f', 0, 0, 0, 0, 0, 2],
-    [b'\\', b'r', 0, 0, 0, 0, 0, 2],
+    [b'\\', b'b', b'0', b'0', b'0', b'0', 0, 2],
+    [b'\\', b't', b'0', b'0', b'0', b'0', 0, 2],
+    [b'\\', b'n', b'0', b'0', b'0', b'0', 0, 2],
+    [b'\\', b'u', b'0', b'0', b'0', b'b', 0, 6],
+    [b'\\', b'f', b'0', b'0', b'0', b'0', 0, 2],
+    [b'\\', b'r', b'0', b'0', b'0', b'0', 0, 2],
     [b'\\', b'u', b'0', b'0', b'0', b'e', 0, 6],
     [b'\\', b'u', b'0', b'0', b'0', b'f', 0, 6],
     [b'\\', b'u', b'0', b'0', b'1', b'0', 0, 6],
